<?php

/***
 *  Class RSSFeed
 *  -------------- 
 *  Description : encapsulates rss feed properties
 *  Updated	    : 17.11.2009
 *  Written by  : ApPHP
 *	
 **/

class RSSFeed {

    private $channelUrl;
    private $channelTitle;
    private $channelDescription;
    private $channelLang;
    private $channelCopyright;
    private $channelDate;
    private $channelCreator;
    private $channelSubject;
    
    private $imageUrl;

    private $arrItems = array();
    private $countItems;
    
	//==========================================================================
    // Class Constructor
	//==========================================================================
	function __construct() {
        $this->countItems=0;
        $this->channelUrl='';
        $this->channelTitle='';
        $this->channelDescription='';
        $this->channelLang='';
        $this->channelCopyright='';
        $this->channelDate='';
        $this->channelCreator='';
        $this->channelSubject='';
        $this->imageUrl='';
    }
    
	//==========================================================================
    // Class Destructor
	//==========================================================================
    function __destruct(){
		// echo 'this object has been destroyed';
    }

	/***
	 * Set Channel
	 *		@param $url
	 *		@param $title
	 *		@param $description
	 *		@param $lang
	 *		@param $copyright
	 *		@param $creator
	 *		@param $subject
	 **/
    function SetChannel($url, $title, $description, $lang, $copyright, $creator, $subject) {
        $this->channelUrl=$url;
        $this->channelTitle=$title;
        $this->channelDescription=$description;
        $this->channelLang=$lang;
        $this->channelCopyright=$copyright;
        $this->channelDate=@date("Y-m-d").'T'.@date("H:i:s").'+02:00';
        $this->channelCreator=$creator;
        $this->channelSubject=$subject;
    }
    
	/***
	 * Set Image
	 *		@param $url
	 **/
    function SetImage($url) {
        $this->imageUrl=$url;
    }
    
	/***
	 * Set Item
	 *		@param $url
	 *		@param $title
	 *		@param $description
	 **/
    function SetItem($url, $title, $description) {
        $this->arrItems[$this->countItems]['url']=$url;
        $this->arrItems[$this->countItems]['title']=$title;
        $this->arrItems[$this->countItems]['description']=$description;
        $this->countItems++;    
    }
    
	/***
	 * Output Feed
	 * 
	 **/
    function OutputFeed() {
        $output =  '<?xml version="1.0" encoding="iso-8859-1"?>'."\n";
        $output .= '<rdf:RDF xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns="http://purl.org/rss/1.0/" xmlns:slash="http://purl.org/rss/1.0/modules/slash/" xmlns:taxo="http://purl.org/rss/1.0/modules/taxonomy/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:syn="http://purl.org/rss/1.0/modules/syndication/" xmlns:admin="http://webns.net/mvcb/" xmlns:feedburner="http://rssnamespace.org/feedburner/ext/1.0">'."\n";
        $output .= '<channel rdf:about="'.$this->channelUrl.'">'."\n";
        $output .= '<title>'.$this->channelTitle.'</title>'."\n";
        $output .= '<link>'.$this->channelUrl.'</link>'."\n";
        $output .= '<description>'.$this->channelDescription.'</description>'."\n";
        $output .= '<dc:language>'.$this->channelLang.'</dc:language>'."\n";
        $output .= '<dc:rights>'.$this->channelCopyright.'</dc:rights>'."\n";
        $output .= '<dc:date>'.$this->channelDate.'</dc:date>'."\n";
        $output .= '<dc:creator>'.$this->channelCreator.'</dc:creator>'."\n";
        $output .= '<dc:subject>'.$this->channelSubject.'</dc:subject>'."\n";
        $output .= '<items>'."\n";
        $output .= '<rdf:Seq>';
        for($k=0; $k<$this->countItems; $k++) {
            $output .= '<rdf:li rdf:resource="'.str_replace("&", "&amp;", $this->arrItems[$k]['url']).'"/>'."\n";
        };
        $output .= '</rdf:Seq>'."\n";
        $output .= '</items>'."\n";
        $output .= '<image rdf:resource="'.$this->imageUrl.'"/>'."\n";
        $output .= '</channel>'."\n";
        for($k=0; $k<$this->countItems; $k++) {
            $output .= '<item rdf:about="'.str_replace("&", "&amp;", $this->arrItems[$k]['url']).'">'."\n";
            $output .= '<title>'.$this->arrItems[$k]['title'].'</title>'."\n";
            $output .= '<link>'.str_replace("&", "&amp;", $this->arrItems[$k]['url']).'</link>'."\n";
            $output .= '<description>'.$this->arrItems[$k]['description'].'</description>'."\n";
            $output .= '<feedburner:origLink>'.str_replace("&", "&amp;", $this->arrItems[$k]['url']).'</feedburner:origLink>'."\n";
            $output .= '</item>'."\n";
        };
        $output .= '</rdf:RDF>'."\n";
        
        return $output;
    }

  	/***
	 * Save Feed
	 * 
	 **/
    function SaveFeed() {
        $handle = fopen("rss.xml",'w+');
        if($handle){
            fwrite($handle, $this->OutputFeed());
            fclose($handle);
        }
    }

}
?>